#########################################################################
#########################################################################

# Parent E. and Rivot E. - An introduction to Hierarchcial Modeling of Ecological Data
# Chapman et al.
# 2012

# R program for Testing Betyp vs Common tag for Tuna
# Chapter 4 - section 4.3

# No BUGS program is required here
# Data are specified in the program (no data file to read)

#########################################################################
#########################################################################

rm(list = ls()) 

y <- 47
n <- 297
teta0 <- 0.22
a <- 1
b <- 1
w <- 0.5*dbinom(y,n,teta0)/(0.5*dbinom(y,n,teta0)+0.5*dbinom(y,n,0.5)*dbeta(0.5,a,b)/dbeta(0.5,a+y,b+n-y))
print(w)

aplusb <- seq(fr=3,to=100000, by=0.2)
teta1 <- 0.2
# teta1 <- teta0
a <- teta1*aplusb
b <- (1-teta1)*aplusb
sigma <- teta1*((1+teta1))/(1+aplusb)
pp <- exp(dbinom(y,n,0.5,log=T)+dbeta(0.5,a,b,log=T)-dbeta(0.5,a+y,b+n-y,log=T))
w <- dbinom(y,n,teta0)/(dbinom(y,n,teta0)+pp)




# windows()

res <- 6
name_figure <- "PostBeliefTagTuna.png"
png(filename = name_figure, height = 500*res, width = 500*res, res=72*res)

plot(sqrt(sigma)/teta1,w,type='l', ylab = "", xlab = "", bty="n", xaxt="n", yaxt="n", xlim = c(0,1.2), ylim=c(0.05,0.25))

axis(side = 1, tick = T, labels = T, cex.axis=1, las=1) 
axis(side = 2, tick = T, labels = T, cex.axis=1)

mtext(side=1, text = expression(paste("Relative standard deviation")), bty="n", line=3, cex=1.3, font = 1)
mtext(side=2, text = expression(paste("Posterior belief of tag equivalence  ",omega)), bty="n", line=3, cex=1.3, font = 1)

which(w==1)
n10<-which(aplusb==10)
n100<-which(aplusb==100)
n1000<-which(aplusb==1000)

text(sqrt(sigma[n100])/teta1,w[n100],"a+b=100", pos = 1)
points(sqrt(sigma[n100])/teta1,w[n100],pch=19)

text(sqrt(sigma[n1000])/teta1,w[n1000],"a+b=1000", pos = 4)
points(sqrt(sigma[n1000])/teta1,w[n1000],pch=19 )

text(sqrt(sigma[n10])/teta1,w[n10],"a+b=10", pos = 4)
points(sqrt(sigma[n10])/teta1,w[n10],pch=19 )

# p-value
2*pbinom(y,n,teta0)

dev.off()



# ---------------------------------------------------

rm(list = ls()) 
n0<-1307 
y0<-249
a0<-4.7 +y0
b0<-17.2 +n0-y0
y<-47
n<-297
pp0<-exp(dbinom(y,n,0.5,log=T)+dbeta(0.5,a0,b0,log=T)-dbeta(0.5,a0+y,b0+n-y,log=T))


teta0<-0.22
teta0<-0.2
aplusb<-seq(fr=3,to=100000, by=0.2)
a<-teta0*aplusb
b<-(1-teta0)*aplusb
sigma<-teta0*((1+teta0))/(1+aplusb)
pp<-exp(dbinom(y,n,0.5,log=T)+dbeta(0.5,a,b,log=T)-dbeta(0.5,a+y,b+n-y,log=T))
w<-pp0/(pp0+pp)
w0<-exp(dbinom(y,n,teta0,log=T))/(exp(dbinom(y,n,teta0,log=T))+pp)
plot(sqrt(sigma)/teta0,w,ylim=c(0,1),xlab="relative standart deviation",ylab="Posterior belief of tag equivalence (w)",typ='l')


Bdirac<-exp(-dbeta(teta0,a,b,log=T)+dbeta(teta0,a+y,b+n-y,log=T))
B01<-exp(-dbeta(teta0,a,b,log=T)+dbeta(teta0,a+y,b+n-y,log=T)+dbeta(teta0,a0,b0,log=T)-dbeta(teta0,a0+y,b0+n-y,log=T))
plot(sqrt(sigma)/teta0,B01/(1+B01),ylim=c(0,1),xlab="relative standart deviation",ylab="Posterior belief of tag equivalence (w)",typ='l')
lines(sqrt(sigma)/teta0,Bdirac/(1+Bdirac),col="red")
which(w==1)
n10<-which(aplusb==10)
n100<-which(aplusb==100)
n1000<-which(aplusb==1000)
text(sqrt(sigma[n100])/teta0,w[n100]-0.005,"a+b=100")
points(sqrt(sigma[n100])/teta0,w[n100],pch=23)
text(0.09+sqrt(sigma[n1000])/teta0,w[n1000]-0.005,"a+b=1000")
points(sqrt(sigma[n1000])/teta0,w[n1000])
text(-0.03+sqrt(sigma[n10])/teta0,w[n10]-0.005,"a+b=10")
points(sqrt(sigma[n10])/teta0,w[n10])

#pvalue
2*pbinom(y,n,teta0)







